pub struct NdRange<const DIMENSIONS: usize = 1> {
pub group_size: Range<DIMENSIONS>,
pub local_size: Range<DIMENSIONS>,
}Expand description
The NdRange struct defines the iteration domain of both the work-groups and the overall
dispatch.
An NdRange comprises two Range parameters: the whole range over which the kernel is to be
executed and the range of each work group.
Fields
group_size: Range<DIMENSIONS>local_size: Range<DIMENSIONS>Implementations