pub type Range<const DIMENSIONS: usize = 1> = [u64; DIMENSIONS];Expand description
Range is a 1D, 2D or 3D vector that defines the iteration domain of either a single work-group
in a parallel dispatch, or the overall dimensions of the dispatch.
pub type Range<const DIMENSIONS: usize = 1> = [u64; DIMENSIONS];Range is a 1D, 2D or 3D vector that defines the iteration domain of either a single work-group
in a parallel dispatch, or the overall dimensions of the dispatch.